import { db } from '../db';
import type { Task, TaskAssignment } from './model';

export class TaskService {
  static createTask(task: Omit<Task, 'id'>, assignments: Omit<TaskAssignment, 'task_id'>[]) {
    return db.transaction(() => {
      const insertTask = db.prepare(`
        INSERT INTO tasks (description, due_date, group_id)
        VALUES (?, ?, ?)
        RETURNING id
      `);
      
      const taskResult = insertTask.get(
        task.description,
        task.due_date?.toISOString(),
        task.group_id
      ) as { id: number };
      
      const insertAssignment = db.prepare(`
        INSERT INTO task_assignments (task_id, user_id, assigned_by)
        VALUES (?, ?, ?)
      `);
      
      assignments.forEach(assignment => {
        insertAssignment.run(
          taskResult.id,
          assignment.user_id,
          assignment.assigned_by
        );
      });
      
      return taskResult.id;
    });
  }

  // We'll add more methods here as we progress
}
